# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1FoldersFolderIdPatchRequest(BaseModel):
    """
    ApiV1FoldersFolderIdPatchRequest
    """
    workspace_id: StrictStr = Field(default=..., alias="workspaceId", description="The ID of the project where the folder is located.")
    environment: StrictStr = Field(default=..., description="The slug of the environment where the folder is located.")
    name: StrictStr = Field(default=..., description="The new name of the folder.")
    path: Optional[StrictStr] = Field(default='/', description="The path of the folder to update.")
    directory: Optional[StrictStr] = Field(default='/', description="The new directory of the folder to update. (Deprecated in favor of path)")
    __properties = ["workspaceId", "environment", "name", "path", "directory"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1FoldersFolderIdPatchRequest:
        """Create an instance of ApiV1FoldersFolderIdPatchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1FoldersFolderIdPatchRequest:
        """Create an instance of ApiV1FoldersFolderIdPatchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1FoldersFolderIdPatchRequest.parse_obj(obj)

        _obj = ApiV1FoldersFolderIdPatchRequest.parse_obj({
            "workspace_id": obj.get("workspaceId"),
            "environment": obj.get("environment"),
            "name": obj.get("name"),
            "path": obj.get("path") if obj.get("path") is not None else '/',
            "directory": obj.get("directory") if obj.get("directory") is not None else '/'
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth(BaseModel):
    """
    ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth
    """
    id: StrictStr = Field(...)
    access_token_ttl: Optional[Union[StrictFloat, StrictInt]] = Field(default=7200, alias="accessTokenTTL")
    access_token_max_ttl: Optional[Union[StrictFloat, StrictInt]] = Field(default=7200, alias="accessTokenMaxTTL")
    access_token_num_uses_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="accessTokenNumUsesLimit")
    access_token_trusted_ips: Optional[Any] = Field(default=None, alias="accessTokenTrustedIps")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    identity_id: StrictStr = Field(default=..., alias="identityId")
    kubernetes_host: StrictStr = Field(default=..., alias="kubernetesHost")
    allowed_namespaces: StrictStr = Field(default=..., alias="allowedNamespaces")
    allowed_names: StrictStr = Field(default=..., alias="allowedNames")
    allowed_audience: StrictStr = Field(default=..., alias="allowedAudience")
    __properties = ["id", "accessTokenTTL", "accessTokenMaxTTL", "accessTokenNumUsesLimit", "accessTokenTrustedIps", "createdAt", "updatedAt", "identityId", "kubernetesHost", "allowedNamespaces", "allowedNames", "allowedAudience"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth:
        """Create an instance of ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if access_token_trusted_ips (nullable) is None
        # and __fields_set__ contains the field
        if self.access_token_trusted_ips is None and "access_token_trusted_ips" in self.__fields_set__:
            _dict['accessTokenTrustedIps'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth:
        """Create an instance of ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth.parse_obj(obj)

        _obj = ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth.parse_obj({
            "id": obj.get("id"),
            "access_token_ttl": obj.get("accessTokenTTL") if obj.get("accessTokenTTL") is not None else 7200,
            "access_token_max_ttl": obj.get("accessTokenMaxTTL") if obj.get("accessTokenMaxTTL") is not None else 7200,
            "access_token_num_uses_limit": obj.get("accessTokenNumUsesLimit") if obj.get("accessTokenNumUsesLimit") is not None else 0,
            "access_token_trusted_ips": obj.get("accessTokenTrustedIps"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "identity_id": obj.get("identityId"),
            "kubernetes_host": obj.get("kubernetesHost"),
            "allowed_namespaces": obj.get("allowedNamespaces"),
            "allowed_names": obj.get("allowedNames"),
            "allowed_audience": obj.get("allowedAudience")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, constr
from infisicalapi_client.models.api_v1_additional_privilege_identity_patch_request_privilege_details import ApiV1AdditionalPrivilegeIdentityPatchRequestPrivilegeDetails

class ApiV1AdditionalPrivilegeIdentityPatchRequest(BaseModel):
    """
    ApiV1AdditionalPrivilegeIdentityPatchRequest
    """
    privilege_slug: constr(strict=True, min_length=1) = Field(default=..., alias="privilegeSlug", description="The slug of the privilege to update.")
    identity_id: constr(strict=True, min_length=1) = Field(default=..., alias="identityId", description="The ID of the identity to update.")
    project_slug: constr(strict=True, min_length=1) = Field(default=..., alias="projectSlug", description="The slug of the project of the identity in.")
    privilege_details: ApiV1AdditionalPrivilegeIdentityPatchRequestPrivilegeDetails = Field(default=..., alias="privilegeDetails")
    __properties = ["privilegeSlug", "identityId", "projectSlug", "privilegeDetails"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AdditionalPrivilegeIdentityPatchRequest:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPatchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of privilege_details
        if self.privilege_details:
            _dict['privilegeDetails'] = self.privilege_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AdditionalPrivilegeIdentityPatchRequest:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPatchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AdditionalPrivilegeIdentityPatchRequest.parse_obj(obj)

        _obj = ApiV1AdditionalPrivilegeIdentityPatchRequest.parse_obj({
            "privilege_slug": obj.get("privilegeSlug"),
            "identity_id": obj.get("identityId"),
            "project_slug": obj.get("projectSlug"),
            "privilege_details": ApiV1AdditionalPrivilegeIdentityPatchRequestPrivilegeDetails.from_dict(obj.get("privilegeDetails")) if obj.get("privilegeDetails") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

class ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership(BaseModel):
    """
    ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership
    """
    id: StrictStr = Field(...)
    role: StrictStr = Field(...)
    status: Optional[StrictStr] = 'invited'
    invite_email: Optional[StrictStr] = Field(default=None, alias="inviteEmail")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    user_id: Optional[StrictStr] = Field(default=None, alias="userId")
    org_id: StrictStr = Field(default=..., alias="orgId")
    role_id: Optional[StrictStr] = Field(default=None, alias="roleId")
    project_favorites: Optional[conlist(StrictStr)] = Field(default=None, alias="projectFavorites")
    is_active: Optional[StrictBool] = Field(default=True, alias="isActive")
    __properties = ["id", "role", "status", "inviteEmail", "createdAt", "updatedAt", "userId", "orgId", "roleId", "projectFavorites", "isActive"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership:
        """Create an instance of ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if invite_email (nullable) is None
        # and __fields_set__ contains the field
        if self.invite_email is None and "invite_email" in self.__fields_set__:
            _dict['inviteEmail'] = None

        # set to None if user_id (nullable) is None
        # and __fields_set__ contains the field
        if self.user_id is None and "user_id" in self.__fields_set__:
            _dict['userId'] = None

        # set to None if role_id (nullable) is None
        # and __fields_set__ contains the field
        if self.role_id is None and "role_id" in self.__fields_set__:
            _dict['roleId'] = None

        # set to None if project_favorites (nullable) is None
        # and __fields_set__ contains the field
        if self.project_favorites is None and "project_favorites" in self.__fields_set__:
            _dict['projectFavorites'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership:
        """Create an instance of ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership.parse_obj(obj)

        _obj = ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership.parse_obj({
            "id": obj.get("id"),
            "role": obj.get("role"),
            "status": obj.get("status") if obj.get("status") is not None else 'invited',
            "invite_email": obj.get("inviteEmail"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "user_id": obj.get("userId"),
            "org_id": obj.get("orgId"),
            "role_id": obj.get("roleId"),
            "project_favorites": obj.get("projectFavorites"),
            "is_active": obj.get("isActive") if obj.get("isActive") is not None else True
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential import ApiV1ExternalKmsPostRequestProviderInputsCredential

class ApiV1ExternalKmsPostRequestProviderInputs(BaseModel):
    """
    ApiV1ExternalKmsPostRequestProviderInputs
    """
    credential: ApiV1ExternalKmsPostRequestProviderInputsCredential = Field(...)
    aws_region: constr(strict=True, min_length=1) = Field(default=..., alias="awsRegion", description="AWS region to connect")
    kms_key_id: Optional[StrictStr] = Field(default=None, alias="kmsKeyId", description="A pre existing AWS KMS key id to be used for encryption. If not provided a kms key will be generated.")
    __properties = ["credential", "awsRegion", "kmsKeyId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1ExternalKmsPostRequestProviderInputs:
        """Create an instance of ApiV1ExternalKmsPostRequestProviderInputs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of credential
        if self.credential:
            _dict['credential'] = self.credential.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1ExternalKmsPostRequestProviderInputs:
        """Create an instance of ApiV1ExternalKmsPostRequestProviderInputs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1ExternalKmsPostRequestProviderInputs.parse_obj(obj)

        _obj = ApiV1ExternalKmsPostRequestProviderInputs.parse_obj({
            "credential": ApiV1ExternalKmsPostRequestProviderInputsCredential.from_dict(obj.get("credential")) if obj.get("credential") is not None else None,
            "aws_region": obj.get("awsRegion"),
            "kms_key_id": obj.get("kmsKeyId")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request import ApiV1AdditionalPrivilegeIdentityPermanentPostRequest  # noqa: E501

class TestApiV1AdditionalPrivilegeIdentityPermanentPostRequest(unittest.TestCase):
    """ApiV1AdditionalPrivilegeIdentityPermanentPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequest:
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdditionalPrivilegeIdentityPermanentPostRequest`
        """
        model = ApiV1AdditionalPrivilegeIdentityPermanentPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequest(
                identity_id = '0',
                project_slug = '0',
                slug = '0',
                permissions = [
                    infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner._api_v1_workspace__projectSlug__roles_post_request_permissions_inner(
                        action = 'read', 
                        subject = 'role', 
                        conditions = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions(
                            environment = '', 
                            secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                                __glob = '0', ), ), )
                    ],
                privilege_permission = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission(
                    actions = [
                        'read'
                        ], 
                    subject = 'secrets', 
                    conditions = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission_conditions(
                        environment = '', 
                        secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                            __glob = '0', ), ), )
            )
        else:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequest(
                identity_id = '0',
                project_slug = '0',
        )
        """

    def testApiV1AdditionalPrivilegeIdentityPermanentPostRequest(self):
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from infisicalapi_client.models.api_v1_integration_post_request_metadata import ApiV1IntegrationPostRequestMetadata

class ApiV1IntegrationPostRequest(BaseModel):
    """
    ApiV1IntegrationPostRequest
    """
    integration_auth_id: StrictStr = Field(default=..., alias="integrationAuthId", description="The ID of the integration auth object to link with integration.")
    app: Optional[StrictStr] = Field(default=None, description="The name of the external integration providers app entity that you want to sync secrets with. Used in Netlify, GitHub, Vercel integrations.")
    is_active: Optional[StrictBool] = Field(default=True, alias="isActive", description="Whether the integration should be active or disabled.")
    app_id: Optional[StrictStr] = Field(default=None, alias="appId", description="The ID of the external integration providers app entity that you want to sync secrets with. Used in Netlify, GitHub, Vercel integrations.")
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath", description="The path of the secrets to sync secrets from.")
    source_environment: StrictStr = Field(default=..., alias="sourceEnvironment", description="The environment to sync secret from.")
    target_environment: Optional[StrictStr] = Field(default=None, alias="targetEnvironment", description="The target environment of the integration provider. Used in cloudflare pages, TeamCity, Gitlab integrations.")
    target_environment_id: Optional[StrictStr] = Field(default=None, alias="targetEnvironmentId", description="The target environment id of the integration provider. Used in cloudflare pages, teamcity, gitlab integrations.")
    target_service: Optional[StrictStr] = Field(default=None, alias="targetService", description="The service based grouping identifier of the external provider. Used in Terraform cloud, Checkly, Railway and NorthFlank")
    target_service_id: Optional[StrictStr] = Field(default=None, alias="targetServiceId", description="The service based grouping identifier ID of the external provider. Used in Terraform cloud, Checkly, Railway and NorthFlank")
    owner: Optional[StrictStr] = Field(default=None, description="External integration providers service entity owner. Used in Github.")
    url: Optional[StrictStr] = Field(default=None, description="The self-hosted URL of the platform to integrate with")
    path: Optional[StrictStr] = Field(default=None, description="Path to save the synced secrets. Used by Gitlab, AWS Parameter Store, Vault")
    region: Optional[StrictStr] = Field(default=None, description="AWS region to sync secrets to.")
    scope: Optional[StrictStr] = Field(default=None, description="Scope of the provider. Used by Github, Qovery")
    metadata: Optional[ApiV1IntegrationPostRequestMetadata] = None
    __properties = ["integrationAuthId", "app", "isActive", "appId", "secretPath", "sourceEnvironment", "targetEnvironment", "targetEnvironmentId", "targetService", "targetServiceId", "owner", "url", "path", "region", "scope", "metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1IntegrationPostRequest:
        """Create an instance of ApiV1IntegrationPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1IntegrationPostRequest:
        """Create an instance of ApiV1IntegrationPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1IntegrationPostRequest.parse_obj(obj)

        _obj = ApiV1IntegrationPostRequest.parse_obj({
            "integration_auth_id": obj.get("integrationAuthId"),
            "app": obj.get("app"),
            "is_active": obj.get("isActive") if obj.get("isActive") is not None else True,
            "app_id": obj.get("appId"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "source_environment": obj.get("sourceEnvironment"),
            "target_environment": obj.get("targetEnvironment"),
            "target_environment_id": obj.get("targetEnvironmentId"),
            "target_service": obj.get("targetService"),
            "target_service_id": obj.get("targetServiceId"),
            "owner": obj.get("owner"),
            "url": obj.get("url"),
            "path": obj.get("path"),
            "region": obj.get("region"),
            "scope": obj.get("scope"),
            "metadata": ApiV1IntegrationPostRequestMetadata.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission  # noqa: E501

class TestApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(unittest.TestCase):
    """ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission:
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission`
        """
        model = ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission()  # noqa: E501
        if include_optional:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(
                actions = [
                    'read'
                    ],
                subject = 'secrets',
                conditions = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission_conditions(
                    environment = '', 
                    secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                        __glob = '0', ), )
            )
        else:
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(
                actions = [
                    'read'
                    ],
                subject = 'secrets',
                conditions = infisicalapi_client.models._api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions._api_v1_additional_privilege_identity_permanent_post_request_privilegePermission_conditions(
                    environment = '', 
                    secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_request_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_request_permissions_inner_conditions_secretPath(
                        __glob = '0', ), ),
        )
        """

    def testApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission(self):
        """Test ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_admin_signup_post_request import ApiV1AdminSignupPostRequest  # noqa: E501

class TestApiV1AdminSignupPostRequest(unittest.TestCase):
    """ApiV1AdminSignupPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AdminSignupPostRequest:
        """Test ApiV1AdminSignupPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AdminSignupPostRequest`
        """
        model = ApiV1AdminSignupPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1AdminSignupPostRequest(
                email = '',
                password = '',
                first_name = '',
                last_name = '',
                protected_key = '',
                protected_key_iv = '',
                protected_key_tag = '',
                public_key = '',
                encrypted_private_key = '',
                encrypted_private_key_iv = '',
                encrypted_private_key_tag = '',
                salt = '',
                verifier = ''
            )
        else:
            return ApiV1AdminSignupPostRequest(
                email = '',
                password = '',
                first_name = '',
                protected_key = '',
                protected_key_iv = '',
                protected_key_tag = '',
                public_key = '',
                encrypted_private_key = '',
                encrypted_private_key_iv = '',
                encrypted_private_key_tag = '',
                salt = '',
                verifier = '',
        )
        """

    def testApiV1AdminSignupPostRequest(self):
        """Test ApiV1AdminSignupPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
